0.1.3
=====

2025-12-29

- 4_: emit warning if `psutil.heap_info()` is not available.
- 5_: can't install on Python 3.8 due to 'license' key in pyproject.toml not
  being compatible across Python versions.

0.1.2
=====

2025-12-24

- 3_: the source distribution was missing a lot of files due to MANIFEST.in not
  being present.
- 2_: list test dependencies in pyproject.toml so that they can be installed
  via `pip install psleak[test]`.

0.1.1
=====

2025-12-23

* fix ``TypeError: dataclass() got an unexpected keyword argument 'slots'``.

0.1.0
=====

2025-12-21

* initial release

.. _1: https://github.com/giampaolo/psleak/issues/1
.. _2: https://github.com/giampaolo/psleak/issues/2
.. _3: https://github.com/giampaolo/psleak/issues/3
.. _4: https://github.com/giampaolo/psleak/issues/4
.. _5: https://github.com/giampaolo/psleak/issues/5
.. _6: https://github.com/giampaolo/psleak/issues/6
.. _7: https://github.com/giampaolo/psleak/issues/7
.. _8: https://github.com/giampaolo/psleak/issues/8
.. _9: https://github.com/giampaolo/psleak/issues/9
.. _10: https://github.com/giampaolo/psleak/issues/10
.. _11: https://github.com/giampaolo/psleak/issues/11
.. _12: https://github.com/giampaolo/psleak/issues/12
.. _13: https://github.com/giampaolo/psleak/issues/13
.. _14: https://github.com/giampaolo/psleak/issues/14
.. _15: https://github.com/giampaolo/psleak/issues/15
.. _16: https://github.com/giampaolo/psleak/issues/16
.. _17: https://github.com/giampaolo/psleak/issues/17
.. _18: https://github.com/giampaolo/psleak/issues/18
.. _19: https://github.com/giampaolo/psleak/issues/19
.. _20: https://github.com/giampaolo/psleak/issues/20
.. _21: https://github.com/giampaolo/psleak/issues/21
.. _22: https://github.com/giampaolo/psleak/issues/22
.. _23: https://github.com/giampaolo/psleak/issues/23
.. _24: https://github.com/giampaolo/psleak/issues/24
.. _25: https://github.com/giampaolo/psleak/issues/25
.. _26: https://github.com/giampaolo/psleak/issues/26
.. _27: https://github.com/giampaolo/psleak/issues/27
.. _28: https://github.com/giampaolo/psleak/issues/28
.. _29: https://github.com/giampaolo/psleak/issues/29
.. _30: https://github.com/giampaolo/psleak/issues/30
